#
# spec file for package ghc-servant
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name servant
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.20.2
Release:        1.13
Summary:        A family of combinators for defining webservices APIs
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-attoparsec-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-bifunctors-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-case-insensitive-prof
BuildRequires:  ghc-constraints-devel
BuildRequires:  ghc-constraints-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-http-api-data-devel
BuildRequires:  ghc-http-api-data-prof
BuildRequires:  ghc-http-media-devel
BuildRequires:  ghc-http-media-prof
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http-types-prof
BuildRequires:  ghc-mmorph-devel
BuildRequires:  ghc-mmorph-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-network-uri-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-singleton-bool-devel
BuildRequires:  ghc-singleton-bool-prof
BuildRequires:  ghc-sop-core-devel
BuildRequires:  ghc-sop-core-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-vault-devel
BuildRequires:  ghc-vault-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-quickcheck-instances-prof
%endif

%description
A family of combinators for defining webservices APIs and serving them .
You can learn about the basics in the
<http://docs.servant.dev/en/stable/tutorial/index.html tutorial>. .
<https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md
CHANGELOG>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri Aug 30 2024 Peter Simons <psimons@suse.com>
- Update servant to version 0.20.2.
  0.20.2
  - ---
  - Full query string helpers [#1604](https://github.com/haskell-servant/servant/pull/1604)
    This PR introduces `DeepQuery`, a route combinator that implements a pattern commonly known as deep objects.
    It builds upon the convention of using `[]` for a list of parameters:
    `books?filter[search]=value&filter[author][name]=value`.
    The corresponding type would be `DeepQuery "filter" BookQuery :> Get '[JSON] [Book]`.
  - Add IsIn instance for NamedRoutes [#1707](https://github.com/haskell-servant/servant/pull/1707)
  - Renamed `AtLeastOneFragment` type class to `AtMostOneFragment` [#1727](https://github.com/haskell-servant/servant/pull/1727)
    The previously named `AtLeastOneFragment` type class defined in the
    `Servant.API.TypeLevel` module has been renamed to `AtMostOneFragment`,
    since the previous name was misleading.
  - Use `Header'` in response headers. [#1697](https://github.com/haskell-servant/servant/pull/1697)
    Use `Header'` instead of `Header` in response, so it's possible to provide
    `Description`, for example:
    ```
    type PaginationTotalCountHeader =
    Header'
    '[ Description "Indicates to the client total count of items in collection"
    , Optional
    , Strict
    ]
    "Total-Count"
    Int
    ```
    Note: if you want to add header with description you should use `addHeader'`
    or `noHeader'` which accepts `Header'` with all modifiers.
* Mon Aug 12 2024 Peter Simons <psimons@suse.com>
- Update servant to version 0.20.1 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri May 17 2024 Peter Simons <psimons@suse.com>
- Update servant to version 0.20.1 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov 27 2023 Peter Simons <psimons@suse.com>
- Update servant to version 0.20.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Oct  2 2023 Peter Simons <psimons@suse.com>
- Update servant to version 0.20.1.
  0.20.1
  - ---
  - Support aeson-2.2 [#1695](https://github.com/haskell-servant/servant/pull/1695)
  0.20
  - ---
  - Headers support in UVerb responses [#1570](https://github.com/haskell-servant/servant/issues/1570) [#1571](https://github.com/haskell-servant/servant/pull/1571)
  - Generalize type of `Servant.Types.SourceT.source` to any foldable [#1593](https://github.com/haskell-servant/servant/pull/1593)
  - Make `Mime(Un)Render PlainText String` instances encode/decode UTF-8 [#1645](https://github.com/haskell-servant/servant/issues/1645)
  - Add HasStatus instance for Headers (that defers StatusOf to underlying value) [#1649](https://github.com/haskell-servant/servant/pull/1649)
  - Make fromSourceIO run in IO [#1661](https://github.com/haskell-servant/servant/pull/1661)
    Some streaming abstractions, like io-streams, require stateful
    initialization. Since all actual call sites of `fromSourceIO`
    are in a context where `IO` actions can be executed, these
    streaming sources can be accomodated by having letting
    `fromSourceIO` run in `IO`.
    To migrate your existing `FromSourceIO` instance, simply put
    a `pure`/`return` in front of it.
  - Fix the handling of multiple headers with the same name. [#1666](https://github.com/haskell-servant/servant/pull/1666)
* Fri Jul  7 2023 Peter Simons <psimons@suse.com>
- Update servant to version 0.19.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Mar 13 2023 Peter Simons <psimons@suse.com>
- Update servant to version 0.19.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Oct 27 2022 Peter Simons <psimons@suse.com>
- Update servant to version 0.19.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/servant-0.19.1/src/CHANGELOG.md
* Mon Mar 21 2022 Peter Simons <psimons@suse.com>
- Update servant to version 0.19 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Feb 23 2022 Peter Simons <psimons@suse.com>
- Update servant to version 0.19 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Feb  2 2022 Peter Simons <psimons@suse.com>
- Update servant to version 0.19.
  Package versions follow the [Package Versioning Policy](https://pvp.haskell.org/): in A.B.C, bumps to either A or B represent major versions.
  0.19
  - ---
  [#]## Significant changes
  - Drop support for GHC < 8.6.
  - Support GHC 9.0 (GHC 9.2 should work as well, but isn't fully tested yet).
  - Support Aeson 2 ([#1475](https://github.com/haskell-servant/servant/pull/1475)),
    which fixes a [DOS vulnerability](https://github.com/haskell/aeson/issues/864)
    related to hash collisions.
  - Add `NamedRoutes` combinator, making support for records first-class in Servant
    ([#1388](https://github.com/haskell-servant/servant/pull/1388)).
    Users can now directly mark part as an API as defined by a record, instead of
    using `(:<|>)` to combine routes. Concretely, the anonymous:
    ```haskell
    type API =
    "version" :> Get '[JSON] String :<|>
    "products" :> Get '[JSON] [Product]
    ```
    can be replaced with the explicitly-named:
    ```haskell
    type API = NamedRoutes NamedAPI
    data NamedAPI mode = NamedAPI
    { version :: mode :- "version" :> Get '[JSON] String
    , products :: mode :- "products" :> Get '[JSON] [Product]
    }
    ```
    `NamedRoutes` builds upon `servant-generic`, but improves usability by freeing
    users from the need to perform `toServant` / `fromServant` conversions
    manually. Serving `NamedRoutes NamedAPI` is now done directly by providing a
    record of handlers, and servant generates clients directly as records as well.
    In particular, it makes it much more practical to work with nested hierarchies
    of named routes.
    Two convenience functions, `(//)` and `(/:)`, have been added to make the
    usage of named route hierarchies more pleasant:
    ```haskell
    rootClient :: RootApi (AsClientT ClientM)
    rootClient = client (Proxy @API)
    hello :: String -> ClientM String
    hello name = rootClient // hello /: name
    endpointClient :: ClientM Person
    endpointClient = client // subApi /: "foobar123" // endpoint
    type Api = NamedRoutes RootApi
    data RootApi mode = RootApi
    { subApi :: mode :- Capture "token" String :> NamedRoutes SubApi
    , hello :: mode :- Capture "name" String :> Get '[JSON] String
    , …
    } deriving Generic
    data SubApi mode = SubApi
    { endpoint :: mode :- Get '[JSON] Person
    , …
    } deriving Generic
    ```
  - Add custom type errors for partially applied combinators
    ([#1289](https://github.com/haskell-servant/servant/pull/1289),
    [#1486](https://github.com/haskell-servant/servant/pull/1486)).
    For example, forgetting to document the expected type for a query parameter,
    as in:
    ``` haskell
    type API = QueryParam "param" :> Get '[JSON] NoContent
    ```
    will raise to the following error when trying to serve the API:
    ```
    • There is no instance for HasServer (QueryParam'
    '[Optional, Strict] "param" :> ...)
    QueryParam' '[Optional, Strict] "1" expects 1 more arguments
    ```
    As a consequence of this change, unsaturated types are now forbidden before `(:>)`.
  - Add a `HeadNoContent` verb ([#1502](https://github.com/haskell-servant/servant/pull/1502)).
  - *servant-client* / *servant-client-core* / *servant-http-streams*:
    Fix erroneous behavior, where only 2XX status codes would be considered
    successful, irrelevant of the status parameter specified by the verb
    combinator. ([#1469](https://github.com/haskell-servant/servant/pull/1469))
  - *servant-client* / *servant-client-core*: Fix `Show` instance for
    `Servant.Client.Core.Request`.
  - *servant-client* / *servant-client-core*: Allow passing arbitrary binary data
    in Query parameters.
    ([#1432](https://github.com/haskell-servant/servant/pull/1432)).
  - *servant-docs*: Generate sample cURL requests
    ([#1401](https://github.com/haskell-servant/servant/pull/1401/files)).
    Breaking change: requires sample header values to be supplied with `headers`.
  [#]## Other changes
  - Various bit rotten cookbooks have been updated and re-introduced on
    [docs.servant.dev](https://docs.servant.dev).
  - Various version bumps.
* Tue Sep  7 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax constraints on base-compat
* Tue Aug 17 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax constraints on transformers-compat
* Thu Jun 24 2021 psimons@suse.com
- Update servant to version 0.18.3.
  0.18.3
  - -----
  [#]## Significant changes
  - Add response header support to UVerb (#1420).
  - Use Capture Description if available (#1423).
  [#]## Other changes
  - Support GHC-9.0.1.
  - Bump `bytestring`, `attoparsec`, `hspec` and `singleton-bool` dependencies.
* Sat May 15 2021 psimons@suse.com
- Update servant to version 0.18.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Apr  6 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax overconstrained deps on singleton-bool
* Thu Mar 25 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax dep on attoparsec
* Tue Jan 19 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax dep on http-api-data
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Dec  9 2020 psimons@suse.com
- Add servant at version 0.18.2.
